# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

import pgm
from pgm.graph.text import Text
from pgm.graph.image import Image

from progressbar_osd import ProgressBarOsd
from dock import Dock

import time, os


# HACK: this is in fact the same as the PlayerOsd
class SlideshowOsd(Dock):

    def __init__(self, canvas, layer,
                 playing_length,
                 width, height,
                 bar_bg_image, bar_fg_image,
                 background_image):

        Dock.__init__(self, canvas, layer, width, height, background_image)

        self._time_position = 0
        self._time_string = ""

        inner_width = width * 0.9
        inner_x = (width - inner_width)/2.0


        # build the title
        self._title = Text()
        self._title.label = ""
#        self._title.font_family = "MgOpen Cosmetica"
        self._title.ellipsize = pgm.TEXT_ELLIPSIZE_MIDDLE
        self._title.fg_color = (220, 220, 220, 255)
        self._title.bg_color = (0, 0, 0, 0)
        self.add(self._title)
        self._title.position = (inner_x, 0.05, 0.0)
        self._title.size = (inner_width, height*0.33)
        self._title.font_height = self._title.height

        # build the time bar
        self._timebar = ProgressBarOsd(canvas, layer, playing_length,
                                       bar_bg_image, bar_fg_image)
        self._timebar.bg_color = (0, 0, 0, 0)
        self.add(self._timebar)
        self._timebar.position = (inner_x, height*(0.33+0.15), 0.0)
        self._timebar.size = (inner_width, height*0.2)
        self._timebar.visible = False
        
        # build the total time text
        self._time = Text()
        self._time.label = ""
#        self._time.font_family = "MgOpen Cosmetica"
        self._time.fg_color = (255, 255, 255, 255)
        self._time.bg_color = (0, 0, 0, 0)
        self._time.alignment = pgm.TEXT_ALIGN_RIGHT
        self.add(self._time)
        self._time.position = (inner_x, height*(0.33+0.2+0.15), 0.001)
        self._time.size = (inner_width, height*0.2)
        self._time.font_height = self._time.height
        self._time.visible = False

        self._title.visible = True

        self.length = playing_length
        
    def length__set(self, length):
        """
        Set the length of the medias
        """
        self._timebar.length = length
        if length > 1:
            self._timebar.visible = True
            self._show_position()
        else:
            self._timebar.visible = False

    def length__get(self):
        """
        Get the length of the medias
        """
        return self._timebar.length


    def title__set(self, title):
        """
        Set the title of the dock
        @param title: the name of a movie or a audio file
        @type title: string
        """
        self._title.label = title
#        self._title.font_height = self._title.height

    def title__get(self):
        """
        Get the current title of the dock
        """
        return self._title.label

    def index__set(self, position):
        """
        Set the position
        """
        self._time_position = position
        self._time.visible = bool(position > 1)
        self._timebar.jump_to_position(position)
        self._show_position()

    def index__get(self):
        """
        Get the current position
        """
        return self._time_position

    def _show_position(self):
        self._time.label = "%s / %s" % (self.index, self.length)
