# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


from elisa.core import player
from elisa.core import common
from elisa.core.input_event import *
from elisa.base_components.controller import Controller

class ElisaController(Controller):
    supported_models = ('base:elisa_model',)
    bindings = {'player': 'player',
                'dvd_player': 'dvd_player',
                'slideshow': 'slideshow',
                'manager': 'manager'}
    
    default_config = {'start_fullscreen': '1'}
    config_doc = {'start_fullscreen': 'whether or not Elisa should start fullscreen'}

    def initialize(self):
        dfr = Controller.initialize(self)
        self.fullscreen = bool(int(self.config.get('start_fullscreen', '0')))
        self._last_player = None
        return dfr
        
    def attribute_set(self, origin, key, old_value, new_value):
        super(ElisaController, self).attribute_set(origin, key, old_value, new_value)
        if key == 'menu_visible':
            if new_value == True:
                if self.slideshow.focused:
                    self._last_player = self.slideshow
                elif self.player.focused:
                    self._last_player = self.player 
                self.focus()
            else:
                if self._last_player == None:
                   self._last_player =  self.player
                self._last_player.focus()
                
        elif key == 'stop_player' and new_value == True:
            if self._last_player == self.slideshow:
                self.slideshow.model.playing = False
                self.slideshow.model.current_index = -1
            else:
                self.player.stopped = True
                self.player.model.state = player.STATES.STOPPED

    def handle_input(self, input_event):
        if input_event.action == EventAction.TOGGLE_FULLSCREEN:
            self.fullscreen = not self.fullscreen
            return True
        elif input_event.action == EventAction.EXIT:
            common.application.stop()
            return True

        elif input_event.action == EventAction.MENU:
            if self.slideshow.focused or self.player.focused:
                self.model.menu_visible = True
            else:
                self.model.menu_visible = False
            return True

        return False

    def model_changed(self, old_model, new_model):
        self.manager.enter_node(self.model.menu)

    def focus(self):
        self.manager.focus()
        
    def focused_changed(self, old_focused, new_focused):
        # FIXME: this relies on the fact that the actions system somehow
        # make the controllers (player, slideshow, etc.) to focus and that the
        # focus notification is going up to their parent (ElisaController)

        for key, value in self.bindings.iteritems(): 
            child_controller = getattr(self, key)
            if child_controller.focused:
                self.focused_window = value
                break
        if self.focused_window == 'slideshow':
            # Pause the video player if a picture is diplayed fullscreen
            # or a slideshow started.
            player_model = self.player.model
            if player_model.media_type == "video" and \
               player_model.state == player.STATES.PLAYING:
                player_model.state = player.STATES.PAUSED
            
