# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

from elisa.core import common
from elisa.core import player

import gtk.gdk, gobject

plugin_registry = common.application.plugin_registry
PigmentView = plugin_registry.get_component_class('pigment:pigment_view')

class ElisaView(PigmentView):

    supported_controllers = ('raval:elisa_controller',)
    bindings = {'player': 'player',
                'dvd_player': 'dvd_player',
                'slideshow': 'slideshow',
                'manager': 'manager',
                'focused_window': 'focused_window'}

    def __init__(self):
        super(ElisaView, self).__init__()
        path = 'raval:focus_transition'
        self._player_in = plugin_registry.create_component(path)
        path = 'raval:unfocus_transition'
        self._player_out = plugin_registry.create_component(path)

    def frontend_changed(self, previous_frontend, new_frontend):
        super(ElisaView, self).frontend_changed(previous_frontend, new_frontend)
        if new_frontend == None:
            return
 
        # FIXME: is this the right place to do that?
        icon_path = self.frontend.theme.get_media("elisa_icon")
        try:
            icon = gtk.gdk.pixbuf_new_from_file(icon_path)
        except gobject.GError:
            self.warning("Icon file not found: %r", icon_path)
        else:
            self.frontend.context.viewport_handle.icon = icon

    def controller_changed(self, old_controller, new_controller):
        if new_controller:
            context = self.frontend.context
            if context.gtk_window is None:
                context.viewport_handle.fullscreen = self.controller.fullscreen
            else:
                if self.controller.fullscreen:
                    context.gtk_window.fullscreen()
                else:
                    context.gtk_window.unfullscreen()
        
    def focused_window__set(self, focused_window):
        self.debug("new focused window: %s" % focused_window)
        players = ('player', 'dvd_player', 'slideshow')

        # FIXME: hackish ways to find out faded views
        slideshow_faded = float(self.slideshow.context_handle.opacity) == 50.
        player_faded = float(self.player.context_handle.opacity) == 50.
        self.debug("player_faded: %r, slideshow_faded: %r",
                   player_faded, slideshow_faded)
        
        try:
            if self._focused_window == focused_window:
                return
            
            old_view = getattr(self, self._focused_window)
        except AttributeError, e:
            # there was no previously focused window
            pass
        else:
            if self._focused_window in players:
                self._player_out.apply(old_view)
                path = 'player_out'
            else:
                if slideshow_faded and focused_window != 'slideshow':
                    path = 'pigment:fadeout_transition'
                    fadeout = plugin_registry.create_component(path)
                    view = self.slideshow
                    fadeout.apply(view)
                    self.debug("Faded out slideshow")
                if player_faded and focused_window != 'player':
                    path = 'pigment:fadeout_transition'
                    fadeout = plugin_registry.create_component(path)
                    view = self.player
                    fadeout.apply(view)
                    self.debug("Faded out player")
                    
                path = 'pigment:fadeout_transition'
                fadeout = plugin_registry.create_component(path)
                fadeout.apply(old_view)
            self.debug("Fade out applied to %r : %r", old_view, path)
            
        new_view = getattr(self, focused_window)

        if focused_window in players:
            self._player_in.apply(new_view)
            path = 'player_in'
        else:
            path = 'pigment:fadein_transition'
            fadein = plugin_registry.create_component(path)
            fadein.apply(new_view)
            
        self.debug("Fade in applied to %r : %r", new_view, path)
        
        self._focused_window = focused_window

    def canvas_resized(self, new_size):
        self.context_handle.regenerate()
