# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
MediaProvider that can access to Elisa's media db
"""


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'

from elisa.base_components.media_provider import MediaProvider
from elisa.core.media_uri import MediaUri
from elisa.core import common
from elisa.core.utils import deferred_action

from twisted.internet import defer, threads


class ElisaMedia(MediaProvider):
    """
    This class implements elisa metadata-like fs support
    """

    def __init__(self):
        MediaProvider.__init__(self)
        self._def_action = deferred_action.DeferredActionsManager()

    def scannable_uri_schemes__get(self):
        return []

    def supported_uri_schemes__get(self):
        return { 'elisa': 0 }

    def _blocking_get_media_type(self, uri): 
        # ElisaMedia always deal with virtual directories
        return { 'file_type' : 'directory', 'mime_type' : '' }

    def is_directory(self, uri):
        return self._def_action.insert_action(0, self._blocking_has_children_with_types, uri, ('audio'))


    def has_children_with_types(self, uri, media_types):
        return self._def_action.insert_action(0, self._blocking_has_children_with_types, uri, media_types)

    def _blocking_has_children_with_types(self, uri, media_types):
        if 'directory' in media_types or 'audio' in media_types:
            db = common.application.media_manager.media_db
            return db.has_children(uri)

        return False

    def _blocking_get_direct_children(self, uri, children_with_info):
        db = common.application.media_manager.media_db
        list_of_children = db.get_uris_by_meta_uri(uri, children_with_info)
        return children_with_info


    def get_direct_children(self, uri, children_with_info):
        return self._def_action.insert_action(0, self._blocking_get_direct_children,
                                              uri, children_with_info)


    def next_location(self, uri, root=None):
        return self._def_action.insert_action(0, self._blocking_next_location, uri, root)

    def _blocking_next_location(self, uri, root):
        db = common.application.media_manager.media_db
        return db.get_next_location(uri, root)

    def uri_is_monitorable(self, uri):
        return False

